@@ -303,7 +303,7 @@ PlayList::PlayList( TQWidget* parent, TQObject *objParent, const char *name ) :
 	browserComb->setCompletionObject( new KURLCompletion( KURLCompletion::DirCompletion ) );
 	browserComb->setAutoDeleteCompletionObject( true );
         browserComb->setMaxItems( 10 );
-        browserComb->setFocusPolicy(TQ_ClickFocus);
+        browserComb->setFocusPolicy(TQWidget::ClickFocus);
 
 
        /* if (!m_medium)
@@ -395,7 +395,7 @@ PlayList::PlayList( TQWidget* parent, TQObject *objParent, const char *name ) :
 	TQLabel* filterLabel = new TQLabel(i18n("Filter") + ":", playlist);
 	h1->addWidget(filterLabel);
 	m_playlistFilter = new KLineEdit(playlist);
-	m_playlistFilter->setFocusPolicy(TQ_ClickFocus);
+	m_playlistFilter->setFocusPolicy(TQWidget::ClickFocus);
 	h1->addWidget(m_playlistFilter);
 	layout->addLayout( h1, 2, 1 );
 
@@ -407,7 +407,7 @@ PlayList::PlayList( TQWidget* parent, TQObject *objParent, const char *name ) :
 	m_playlistSelector->setSizePolicy( TQSizePolicy (TQSizePolicy::MinimumExpanding, TQSizePolicy::Preferred) );
 	m_playlistSelector->setEditable(true);
 	m_playlistSelector->setDuplicatesEnabled(false);
-	m_playlistSelector->setFocusPolicy(TQ_ClickFocus);
+	m_playlistSelector->setFocusPolicy(TQWidget::ClickFocus);
 	TQToolTip::add(m_playlistSelector, i18n("Select the active playlist. To change playlist name edit it and confirm with 'Return'."));
 	h2->addWidget(m_playlistSelector);
 	layout->addLayout( h2, 1, 1 );
