@@ -400,7 +400,7 @@ void Paranoia::run()
 			fn.open( IO_ReadWrite | IO_Truncate );
 			do {
 				buf = paranoia_read_limited( p, paranoiaCallback, 3 );
-				if ( Q_BYTE_ORDER == Q_BIG_ENDIAN ) {
+				if ( TQ_BYTE_ORDER == TQ_BIG_ENDIAN ) {
 					for ( i=0; i<len/2; i++)
 						buf[i] = paraSwap16(buf[i]);
 				}
@@ -458,7 +458,7 @@ void Paranoia::run()
 			len = CDIO_CD_FRAMESIZE_RAW;
 			do {
 				buf = paranoia_read_limited( p, paranoiaCallback, 3 );
-				if ( Q_BYTE_ORDER == Q_BIG_ENDIAN ) {
+				if ( TQ_BYTE_ORDER == TQ_BIG_ENDIAN ) {
 					for ( i=0; i<len/2; i++) {
 						buf[i] = paraSwap16(buf[i]);
 					}
