@@ -33,7 +33,7 @@
 
 class KDE_EXPORT KaffeineAudioEncoder : public KParts::Part
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	KaffeineAudioEncoder(TQObject* parent, const char* name);
