@@ -827,7 +827,7 @@ DvbConfigDialog::DvbConfigDialog( DvbPanel *pan, DVBconfig *dc, TQWidget *parent
 	}
 
 	page = addPage(i18n("Recording"),i18n("DVB Recording Options"),
-		TDEGlobal::instance()->iconLoader()->loadIcon( "drive-harddisk", TDEIcon::NoGroup, TDEIcon::SizeMedium ) );
+		TDEGlobal::instance()->iconLoader()->loadIcon( "drive-harddisk-unmounted", TDEIcon::NoGroup, TDEIcon::SizeMedium ) );
 	vb = new TQVBoxLayout( page, 6, 6 );
 	gb = new TQGroupBox( "", page );
 	grid = new TQGridLayout( gb, 1, 1, 20, 6 );
