@@ -174,7 +174,7 @@ DvbPanel::DvbPanel( TQWidget *parent, TQObject *objParent, const char *name ) :
 	TQToolTip::add( searchBtn, i18n("Search channel(s)"));
 	TQLabel* filterLabel = new TQLabel( i18n("Filter") + ":", panel );
 	searchLE = new KLineEdit( panel );
-	searchLE->setFocusPolicy( TQ_ClickFocus );
+	searchLE->setFocusPolicy( TQWidget::ClickFocus );
 	h1->addWidget( searchBtn );
 	h1->addWidget( filterLabel );
 	h1->addWidget( searchLE );
