@@ -31,9 +31,9 @@
 #include <tqapplication.h>
 #include <tqaccel.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 #include "scandialog.h"
 #include "channeleditor.h"
@@ -55,11 +55,11 @@ ScanDialog::ScanDialog( TQPtrList<DvbStream> *d, TQPtrList<ChannelDesc> *ch, TQS
 	int i, j;
 	TQStringList list, tmp;
 
-	KIconLoader *icon = new KIconLoader();
-	tvPix = icon->loadIcon( "kdvbtv", KIcon::Small );
-	tvcPix = icon->loadIcon( "kdvbtvc", KIcon::Small );
-	raPix = icon->loadIcon( "kdvbra", KIcon::Small );
-	racPix = icon->loadIcon( "kdvbrac", KIcon::Small );
+	TDEIconLoader *icon = new TDEIconLoader();
+	tvPix = icon->loadIcon( "kdvbtv", TDEIcon::Small );
+	tvcPix = icon->loadIcon( "kdvbtvc", TDEIcon::Small );
+	raPix = icon->loadIcon( "kdvbra", TDEIcon::Small );
+	racPix = icon->loadIcon( "kdvbrac", TDEIcon::Small );
 
 	chandesc = ch;
 	dvbsi = 0;
