@@ -34,7 +34,7 @@ DummyPart::DummyPart(TQWidget* parentWidget, const char* widgetName, TQObject* p
   setInstance(DummyPartFactory::instance());
 
  // m_player = new Player(this);
- // m_player->setFocusPolicy(TQ_ClickFocus);
+ // m_player->setFocusPolicy(TQWidget::ClickFocus);
  // setWidget(m_player);
 
   setXMLFile("dummy_part.rc");
@@ -71,7 +71,7 @@ TDEAboutData *DummyPart::createAboutData()
     TDEAboutData* aboutData = new TDEAboutData( "dummypart", I18N_NOOP("DummyPart"),
     "0.1", "Description...",
     TDEAboutData::License_GPL,
-    "(c) 2004, Jürgen Kofler.", 0, "http://kaffeine.sourceforge.net");
+    "(c) 2004, Jürgen Kofler.", 0 );
     aboutData->addAuthor("Jürgen Kofler.",0, "kaffeine@gmx.net");
 
    return aboutData;
@@ -118,3 +118,5 @@ void DummyPart::initActions()
   new TDEAction(i18n("Pause"), "media-playback-pause", Key_Space, this, TQT_SLOT(slotTogglePause()), actionCollection(), "player_pause");
   new TDEAction(i18n("Stop"), "media-playback-stop", Key_Backspace, this, TQT_SLOT(slotStop()), actionCollection(), "player_stop");
 }
+
+#include "dummy_part.moc"
