@@ -79,7 +79,7 @@ GStreamerPart::GStreamerPart( TQWidget* parentWidget, const char* /*widgetName*/
 	kdDebug() << "GStreamerPart: Creating video window" << endl;
 	m_video = new VideoWindow( parentWidget, m_videosink );
 	connect( m_video, TQT_SIGNAL(signalNewFrameSize(const TQSize&)), this, TQT_SIGNAL(signalNewFrameSize(const TQSize&)) );
-	m_video->setFocusPolicy( TQ_ClickFocus );
+	m_video->setFocusPolicy( TQWidget::ClickFocus );
 	setWidget( m_video );
 
 	setXMLFile( "gstreamer_part.rc" );
