@@ -75,7 +75,7 @@ typedef int PostFilter; /* dummy type */
 class KXineWidget : public TQWidget, public TQThread
 {
 
-	Q_OBJECT
+	TQ_OBJECT
   
 
 public:
@@ -316,6 +316,10 @@ protected:
 	void initOSD();
 	virtual void run();
 
+  static int makeVolumeLogarithmic(int volume);
+
+  static bool s_logarithmicVolume;
+
 private:
 #ifndef HAVE_XCB
 	bool x11Event(XEvent *);
