@@ -27,7 +27,7 @@
 
 class PositionSlider : public TQSlider
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
