@@ -123,7 +123,7 @@ XinePart::XinePart(TQWidget* parentWidget, const char* widgetName, TQObject* par
 	connect(m_xine, TQT_SIGNAL(signalXineFatal(const TQString&)), this, TQT_SIGNAL(canceled(const TQString&)));
 	connect(m_xine, TQT_SIGNAL(stopDvb()), this, TQT_SIGNAL(stopDvb()));
 	connect(m_xine, TQT_SIGNAL(signalDvbOSDHidden()), this, TQT_SIGNAL(dvbOSDHide()));
-	m_xine->setFocusPolicy(TQ_ClickFocus);
+	m_xine->setFocusPolicy(TQWidget::ClickFocus);
 	setWidget(m_xine);
 
 	// set our XML-UI resource file
@@ -1417,7 +1417,7 @@ void XinePart::initActions()
 		(m_volume, i18n("Volume"));
 	m_volume->setRange(0, 100);
 	m_volume->setSteps(1, 10);
-	m_volume->setFocusPolicy(TQ_NoFocus);
+	m_volume->setFocusPolicy(TQWidget::NoFocus);
 	m_volume->setFixedWidth(75);
 	connect(m_volume, TQT_SIGNAL(valueChanged(int)), TQT_TQOBJECT(this), TQT_SLOT(slotVolumeChanged(int)));
 	connect(m_xine, TQT_SIGNAL(signalSyncVolume()), TQT_TQOBJECT(this), TQT_SLOT(slotSyncVolume()));
@@ -1429,7 +1429,7 @@ void XinePart::initActions()
 	m_position->setRange(0, 65535);
 	m_position->setSteps(100, 1000);
 	m_position->setTracking(false);
-	m_position->setFocusPolicy(TQ_NoFocus);
+	m_position->setFocusPolicy(TQWidget::NoFocus);
 	m_position->setMinimumWidth(180);
 	connect(m_position, TQT_SIGNAL(sliderMoved(int)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSeekToPosition(int)));
 	connect(m_position, TQT_SIGNAL(sliderLastMove(int)), TQT_TQOBJECT(m_xine), TQT_SLOT(slotSeekToPositionBlocking(int)));
@@ -1443,7 +1443,7 @@ void XinePart::initActions()
 	TQFontMetrics met(TDEGlobalSettings::generalFont());
 	m_playTime->setFixedWidth(met.width("-55:55:55") + 6);
 	m_playTime->setSizePolicy(TQSizePolicy (TQSizePolicy::Fixed, TQSizePolicy::Fixed));
-	m_playTime->setFocusPolicy(TQ_NoFocus);
+	m_playTime->setFocusPolicy(TQWidget::NoFocus);
 	new KWidgetAction(m_playTime, i18n("Playtime"), 0, 0, 0, actionCollection(), "player_playtime");
 	connect(m_playTime, TQT_SIGNAL(pressed()), TQT_TQOBJECT(this), TQT_SLOT(slotButtonTimerPressed()));
 	connect(m_playTime, TQT_SIGNAL(released()), TQT_TQOBJECT(this), TQT_SLOT(slotButtonTimerReleased()));
