@@ -101,7 +101,7 @@ void SystemTray::mousePressEvent(TQMouseEvent *e)
 		KSystemTray::mousePressEvent(e);
 		break;
 	case MidButton:
-		if(!TQT_TQRECT_OBJECT(rect()).contains(e->pos()))
+		if(!rect().contains(e->pos()))
 			return;
 		actionCollection()->action("trayplay")->activate();
 		break;
